Error

Enum Error 

pub enum Error {
Show 17 variants PayloadNotBuilt, HeaderNotBuilt, OutOfBounds { source: &'static str, variable: &'static str, }, SliceTooSmall, InvalidProtocolVersion { value: u8, }, InvalidNackCode { value: u8, }, InvalidActionCode { value: u8, }, InvalidSyncStatus { value: u8, }, InvalidActivationCode { value: u8, }, InvalidActivationType { value: u8, }, InvalidNodeType { value: u8, }, InvalidPowerMode { value: u8, }, InvalidDiagnosticNackCode { value: u8, }, InvalidDiagnosticAckCode { value: u8, }, InvalidPayloadType { value: [u8; 2], }, BufferTooSmall { size: usize, }, SliceError(TryFromSliceError),
}
Custom Error enum for deriving error types across the application and API.

Expand to fit new dependencies using #[from] and implement custom error types with context.

Variants



PayloadNotBuilt

When utilising the builder pattern the payload is not present



HeaderNotBuilt

When utilising the builder pattern the header is not present



OutOfBounds

Errors when accessing a range out of the slices scope.

Fields

source: &'static str

Source struct

variable: &'static str

Destination variable



SliceTooSmall

When a slice is too small to be written to



InvalidProtocolVersion

Invalid ProtocolVersion

Fields

value: u8

Value



InvalidNackCode

Invalid NackCode

Fields

value: u8

Value



InvalidActionCode

Invalid ActionCode

Fields

value: u8

Value



InvalidSyncStatus

Invalid SyncStatus

Fields

value: u8

Value



InvalidActivationCode

Invalid ActivationCode

Fields

value: u8

Value



InvalidActivationType

Invalid ActivationType

Fields

value: u8

Value



InvalidNodeType

Invalid NodeType

Fields

value: u8

Value



InvalidPowerMode

Invalid PowerMode

Fields

value: u8

Value



InvalidDiagnosticNackCode

Invalid DiagnosticNackCode

Fields

value: u8

Value



InvalidDiagnosticAckCode

Invalid DiagnosticAckCode

Fields

value: u8

Value



InvalidPayloadType

Invalid PayloadType

Fields

value: [u8; 2]

Value



BufferTooSmall

When the destination buffer is too small

Fields

size: usize

Size of the buffer



SliceError(TryFromSliceError)

Derived implementation for standard library IO errors