DoipMessage

Struct DoipMessage 

pub struct DoipMessage {
    pub header: DoipHeader,
    pub payload: DoipPayload,
}
The decoded struct of a DoIP packet.

Each DoIP packet contains a header which describes the message, this is outlined in DoipHeader.

Some Payload Types available in DoIP require a payload which is covered by DoipPayload.

Fields

header: DoipHeader

Defined by DoipHeader, the header supplies the information for programs to understand the payload.

payload: DoipPayload

Takes any struct implementing DoipPayload.