ActionCode

Enum ActionCode 

pub enum ActionCode {
Show 17 variants NoFurtherActionRequired = 0, ReservedByIso13400_01 = 1, ReservedByIso13400_02 = 2, ReservedByIso13400_03 = 3, ReservedByIso13400_04 = 4, ReservedByIso13400_05 = 5, ReservedByIso13400_06 = 6, ReservedByIso13400_07 = 7, ReservedByIso13400_08 = 8, ReservedByIso13400_09 = 9, ReservedByIso13400_0A = 10, ReservedByIso13400_0B = 11, ReservedByIso13400_0C = 12, ReservedByIso13400_0D = 13, ReservedByIso13400_0E = 14, ReservedByIso13400_0F = 15, RoutingActivationRequired = 16,
}
Used in Vehicle Announcement Messages to give next steps.

Used to inform the client of further actions which need to be taken on a DoIP server.

Variants



NoFurtherActionRequired = 0

No Further Action Required



ReservedByIso13400_01 = 1

Reserved By ISO-13400 for bytes value 01



ReservedByIso13400_02 = 2

Reserved By ISO-13400 for bytes value 02



ReservedByIso13400_03 = 3

Reserved By ISO-13400 for bytes value 03



ReservedByIso13400_04 = 4

Reserved By ISO-13400 for bytes value 04



ReservedByIso13400_05 = 5

Reserved By ISO-13400 for bytes value 05



ReservedByIso13400_06 = 6

Reserved By ISO-13400 for bytes value 06



ReservedByIso13400_07 = 7

Reserved By ISO-13400 for bytes value 07



ReservedByIso13400_08 = 8

Reserved By ISO-13400 for bytes value 08



ReservedByIso13400_09 = 9

Reserved By ISO-13400 for bytes value 09



ReservedByIso13400_0A = 10

Reserved By ISO-13400 for bytes value 0A



ReservedByIso13400_0B = 11

Reserved By ISO-13400 for bytes value 0B



ReservedByIso13400_0C = 12

Reserved By ISO-13400 for bytes value 0C



ReservedByIso13400_0D = 13

Reserved By ISO-13400 for bytes value 0D



ReservedByIso13400_0E = 14

Reserved By ISO-13400 for bytes value 0E



ReservedByIso13400_0F = 15

Reserved By ISO-13400 for bytes value 0F



RoutingActivationRequired = 16

Routing Activation Required