ActivationCode

Enum ActivationCode 

pub enum ActivationCode {
Show 18 variants DeniedUnknownSourceAddress = 0, DeniedTCPSocketsFull = 1, DeniedTCPSocketAlreadyConnected = 2, DeniedSourceIsAlreadyActive = 3, DeniedMissingAuthentication = 4, DeniedRejectedConfirmation = 5, DeniedUnsupportedRoutingActivationType = 6, DeniedRequestEncryptedTLSConnection = 7, ReservedByIso13400_08 = 8, ReservedByIso13400_09 = 9, ReservedByIso13400_0A = 10, ReservedByIso13400_0B = 11, ReservedByIso13400_0C = 12, ReservedByIso13400_0D = 13, ReservedByIso13400_0E = 14, ReservedByIso13400_0F = 15, SuccessfullyActivated = 16, ActivatedConfirmationRequired = 17,
}
Used in Routing Activation Response for results from a Routing Activation Request.

Used to understand the result of a Routing Activation Request to understand which logical route to take.

Variants



DeniedUnknownSourceAddress = 0

Denied Unknown Source Address



DeniedTCPSocketsFull = 1

Denied TCP Sockets Full



DeniedTCPSocketAlreadyConnected = 2

Denied TCP Socket Already Connected



DeniedSourceIsAlreadyActive = 3

Denied Source Is Already Active



DeniedMissingAuthentication = 4

Denied Missing Authentication



DeniedRejectedConfirmation = 5

Denied Rejected Confirmation



DeniedUnsupportedRoutingActivationType = 6

Denied Unsupported Routing ActivationType



DeniedRequestEncryptedTLSConnection = 7

Denied Request Encrypted TLS Connection



ReservedByIso13400_08 = 8

Reserved By ISO-13400 for bytes value 08



ReservedByIso13400_09 = 9

Reserved By ISO-13400 for bytes value 09



ReservedByIso13400_0A = 10

Reserved By ISO-13400 for bytes value 0A



ReservedByIso13400_0B = 11

Reserved By ISO-13400 for bytes value 0B



ReservedByIso13400_0C = 12

Reserved By ISO-13400 for bytes value 0C



ReservedByIso13400_0D = 13

Reserved By ISO-13400 for bytes value 0D



ReservedByIso13400_0E = 14

Reserved By ISO-13400 for bytes value 0E



ReservedByIso13400_0F = 15

Reserved By ISO-13400 for bytes value 0F



SuccessfullyActivated = 16

Successfully Activated



ActivatedConfirmationRequired = 17

Activated Confirmation Required