pub enum ActivationType {
Default = 0,
WwhObd = 1,
CentralSecurity = 2,
}Expand description
Used in Routing Activation Request to request specific routing types.
Used to customise the routing type requested from the DoIP entity for different
scenarios.
Variants