DoipPayload

Enum DoipPayload 

pub enum DoipPayload {
Show 16 variants GenericNack(GenericNack), VehicleIdentificationRequest(VehicleIdentificationRequest), VehicleIdentificationRequestEid(VehicleIdentificationRequestEid), VehicleIdentificationRequestVin(VehicleIdentificationRequestVin), VehicleAnnouncementMessage(VehicleAnnouncementMessage), RoutingActivationRequest(RoutingActivationRequest), RoutingActivationResponse(RoutingActivationResponse), AliveCheckRequest(AliveCheckRequest), AliveCheckResponse(AliveCheckResponse), EntityStatusRequest(EntityStatusRequest), EntityStatusResponse(EntityStatusResponse), PowerInformationRequest(PowerInformationRequest), PowerInformationResponse(PowerInformationResponse), DiagnosticMessage(DiagnosticMessage), DiagnosticMessageAck(DiagnosticMessageAck), DiagnosticMessageNack(DiagnosticMessageNack),
}
Implemented across DoIP Payload Types for consistent encoding and decoding of buffers.

DoipPayload is implemented for all the DoIP Payload Types for the purpose of consistent encoding and decoding as well as identification within a buffer.

Variants



GenericNack(GenericNack)

GenericNack variant to hold GenericNack struct



VehicleIdentificationRequest(VehicleIdentificationRequest)

VehicleIdentificationRequest variant to hold VehicleIdentificationRequest struct



VehicleIdentificationRequestEid(VehicleIdentificationRequestEid)

VehicleIdentificationRequestEid variant to hold VehicleIdentificationRequestEid struct



VehicleIdentificationRequestVin(VehicleIdentificationRequestVin)

VehicleIdentificationRequestVin variant to hold VehicleIdentificationRequestVin struct



VehicleAnnouncementMessage(VehicleAnnouncementMessage)

VehicleAnnouncementMessage variant to hold VehicleAnnouncementMessage struct



RoutingActivationRequest(RoutingActivationRequest)

RoutingActivationRequest variant to hold RoutingActivationRequest struct



RoutingActivationResponse(RoutingActivationResponse)

RoutingActivationResponse variant to hold RoutingActivationResponse struct



AliveCheckRequest(AliveCheckRequest)

AliveCheckRequest variant to hold AliveCheckRequest struct



AliveCheckResponse(AliveCheckResponse)

AliveCheckResponse variant to hold AliveCheckResponse struct



EntityStatusRequest(EntityStatusRequest)

EntityStatusRequest variant to hold EntityStatusRequest struct



EntityStatusResponse(EntityStatusResponse)

EntityStatusResponse variant to hold EntityStatusResponse struct



PowerInformationRequest(PowerInformationRequest)

PowerInformationRequest variant to hold PowerInformationRequest struct



PowerInformationResponse(PowerInformationResponse)

PowerInformationResponse variant to hold PowerInformationResponse struct



DiagnosticMessage(DiagnosticMessage)

DiagnosticMessage variant to hold DiagnosticMessage struct



DiagnosticMessageAck(DiagnosticMessageAck)

DiagnosticMessageAck variant to hold DiagnosticMessageAck struct



DiagnosticMessageNack(DiagnosticMessageNack)

DiagnosticMessageNack variant to hold DiagnosticMessageNack struct