EntityStatusResponse

Struct EntityStatusResponse 

pub struct EntityStatusResponse {
    pub node_type: NodeType,
    pub max_concurrent_sockets: [u8; 1],
    pub currently_open_sockets: [u8; 1],
    pub max_data_size: [u8; 4],
}
Expected reponse from EntityStatusRequest.

Containing details of the target of the EntityStatusRequest, the EntityStatusResponse provides the program with details pertaining to the active status of the entity.

Fields

node_type: NodeType

The type of entity, either a Gateway or Node

max_concurrent_sockets: [u8; 1]

The number of maximum concurrent TCP sockets allowed on this entity

currently_open_sockets: [u8; 1]

The number of currently open TCP sockets on the entity

max_data_size: [u8; 4]

The max data size allowed to be sent to the entity